@@ -7,6 +7,25 @@ test.calcpower <- function() {
 	gMCP:::calcMultiPower(weights=.tmpGraph@weights, alpha=0.05, G=.tmpGraph@m, muL = list(c(0, 0, 0)), sigmaL = list(c(1, 1, 1)), nL = list(c(10, 10, 10)),sigma = matrix(c(1,0,0,0,1,0,0,0,1), nrow=3), nSim = 10000, type = "quasirandom")
 }
 
+test.api.compatibility <- function() {
+  graph <- BonferroniHolm(4)
+  weights <- graph@weights
+  G <- graph@m
+  alpha <- 0.05
+  mean <- rep(0,4)
+  sigma <- corr.sim <- diag(4)
+  
+  # Old API:
+  suppressWarnings(result1 <- calcPower(weights=weights, alpha=alpha, G=G, mean = mean,
+                                        sigma = sigma, cr = NULL,
+                                        nSim = 10000))
+  
+  # New API:
+  result2 <- calcPower(graph=graph, alpha=alpha, mean = mean,
+           corr.sim = corr.sim, corr.test = NULL,
+           n.sim = 10000)
+}
+
 test.rqmvnorm <- function() {
 	if (gMCP:::tests("extended")) {		
 		# Check whether the correlation is correctly processed
